==> kadaster-gds2-1.4-sources.jar: nl/kadaster/schemas/gds2/service/afgifte_bestandophalen/v20130701/BestandOphalenResponse.java <==

package nl.kadaster.schemas.gds2.service.afgifte_bestandophalen.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.v20130701.BestandOphalenResultaatType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="antwoord" type="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/v20130701}BestandOphalenResultaatType"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "antwoord"
})
@XmlRootElement(name = "BestandOphalenResponse")
public class BestandOphalenResponse {

    @XmlElement(required = true)
    protected BestandOphalenResultaatType antwoord;

    /**
     * Gets the value of the antwoord property.
     * 
     * @return
     *     possible object is
     *     {@link BestandOphalenResultaatType }
     *     
     */
    public BestandOphalenResultaatType getAntwoord() {
        return antwoord;
    }

    /**
     * Sets the value of the antwoord property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandOphalenResultaatType }
     *     
     */
    public void setAntwoord(BestandOphalenResultaatType value) {
        this.antwoord = value;
    }

}

==> kadaster-gds2-2.0-sources.jar: nl/kadaster/schemas/gds2/service/afgifte_bestandophalen/v20130701/BestandOphalenResponse.java <==

package nl.kadaster.schemas.gds2.service.afgifte_bestandophalen.v20130701;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import nl.kadaster.schemas.gds2.afgifte_bestandophalenresultaat.v20130701.BestandOphalenResultaatType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="antwoord" type="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandophalenresultaat/v20130701}BestandOphalenResultaatType"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "antwoord"
})
@XmlRootElement(name = "BestandOphalenResponse")
public class BestandOphalenResponse {

    @XmlElement(required = true)
    protected BestandOphalenResultaatType antwoord;

    /**
     * Gets the value of the antwoord property.
     * 
     * @return
     *     possible object is
     *     {@link BestandOphalenResultaatType }
     *     
     */
    public BestandOphalenResultaatType getAntwoord() {
        return antwoord;
    }

    /**
     * Sets the value of the antwoord property.
     * 
     * @param value
     *     allowed object is
     *     {@link BestandOphalenResultaatType }
     *     
     */
    public void setAntwoord(BestandOphalenResultaatType value) {
        this.antwoord = value;
    }

}
